@@ -224,7 +224,7 @@ class SQLExecute:
             client_flag |= pymysql.constants.CLIENT.MULTI_STATEMENTS
 
         ssl_context = None
-        if ssl:
+        if ssl and ssl.get('enable') is True:
             ssl_context = self._create_ssl_ctx(ssl)
 
         conn = pymysql.connect(
@@ -238,7 +238,7 @@ class SQLExecute:
             charset=charset or '',
             autocommit=True,
             client_flag=client_flag,
-            local_infile=local_infile,
+            local_infile=local_infile or False,
             conv=conv,
             ssl=ssl_context,  # type: ignore[arg-type]
             program_name="mycli",
