@@ -1,15 +1,16 @@
+# type: ignore
+
 import os
 import stat
 import tempfile
 from time import time
 from unittest.mock import patch
 
-import pytest
 from pymysql import ProgrammingError
+import pytest
 
 import mycli.packages.special
-
-from .utils import dbtest, db_connection, send_ctrl_c
+from test.utils import db_connection, dbtest, send_ctrl_c
 
 
 def test_set_get_pager():
@@ -100,7 +101,7 @@ def test_tee_command_error():
     with pytest.raises(OSError):
         with tempfile.NamedTemporaryFile() as f:
             os.chmod(f.name, stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH)
-            mycli.packages.special.execute(None, "tee {}".format(f.name))
+            mycli.packages.special.execute(None, f"tee {f.name}")
 
 
 @dbtest
@@ -108,7 +109,7 @@ def test_tee_command_error():
 def test_favorite_query():
     with db_connection().cursor() as cur:
         query = 'select "✔"'
-        mycli.packages.special.execute(cur, "\\fs check {0}".format(query))
+        mycli.packages.special.execute(cur, f"\\fs check {query}")
         assert next(mycli.packages.special.execute(cur, "\\f check"))[0] == "> " + query
 
 
@@ -151,30 +152,32 @@ def test_pipe_once_command():
 
     with pytest.raises(OSError):
         mycli.packages.special.execute(None, "\\pipe_once /proc/access-denied")
+        mycli.packages.special.write_pipe_once("select 1")
+        mycli.packages.special.flush_pipe_once_if_written(None)
 
     if os.name == "nt":
         mycli.packages.special.execute(None, '\\pipe_once python -c "import sys; print(len(sys.stdin.read().strip()))"')
         mycli.packages.special.write_once("hello world")
-        mycli.packages.special.unset_pipe_once_if_written()
+        mycli.packages.special.flush_pipe_once_if_written(None)
     else:
         with tempfile.NamedTemporaryFile() as f:
             mycli.packages.special.execute(None, "\\pipe_once tee " + f.name)
             mycli.packages.special.write_pipe_once("hello world")
-            mycli.packages.special.unset_pipe_once_if_written()
+            mycli.packages.special.flush_pipe_once_if_written(None)
             f.seek(0)
             assert f.read() == b"hello world\n"
 
 
 def test_parseargfile():
     """Test that parseargfile expands the user directory."""
-    expected = {"file": os.path.join(os.path.expanduser("~"), "filename"), "mode": "a"}
+    expected = (os.path.join(os.path.expanduser("~"), "filename"), "a")
 
     if os.name == "nt":
         assert expected == mycli.packages.special.iocommands.parseargfile("~\\filename")
     else:
         assert expected == mycli.packages.special.iocommands.parseargfile("~/filename")
 
-    expected = {"file": os.path.join(os.path.expanduser("~"), "filename"), "mode": "w"}
+    expected = (os.path.join(os.path.expanduser("~"), "filename"), "w")
     if os.name == "nt":
         assert expected == mycli.packages.special.iocommands.parseargfile("-o ~\\filename")
     else:
@@ -195,8 +198,8 @@ def test_watch_query_iteration():
     """Test that a single iteration of the result of `watch_query` executes
     the desired query and returns the given results."""
     expected_value = "1"
-    query = "SELECT {0!s}".format(expected_value)
-    expected_title = "> {0!s}".format(query)
+    query = f"SELECT {expected_value}"
+    expected_title = f"> {query}"
     with db_connection().cursor() as cur:
         result = next(mycli.packages.special.iocommands.watch_query(arg=query, cur=cur))
     assert result[0] == expected_title
@@ -218,14 +221,14 @@ def test_watch_query_full():
     watch_seconds = 0.3
     wait_interval = 1
     expected_value = "1"
-    query = "SELECT {0!s}".format(expected_value)
-    expected_title = "> {0!s}".format(query)
-    expected_results = 4
+    query = f"SELECT {expected_value}"
+    expected_title = f"> {query}"
+    expected_results = [4, 5]
     ctrl_c_process = send_ctrl_c(wait_interval)
     with db_connection().cursor() as cur:
-        results = list(mycli.packages.special.iocommands.watch_query(arg="{0!s} {1!s}".format(watch_seconds, query), cur=cur))
+        results = list(mycli.packages.special.iocommands.watch_query(arg=f"{watch_seconds} {query}", cur=cur))
     ctrl_c_process.join(1)
-    assert len(results) == expected_results
+    assert len(results) in expected_results
     for result in results:
         assert result[0] == expected_title
         assert result[2][0] == expected_value
@@ -280,14 +283,14 @@ def test_watch_query_interval_clear(clear_mock):
     seconds = 1.0
     watch_query = mycli.packages.special.iocommands.watch_query
     with db_connection().cursor() as cur:
-        test_asserts(watch_query("{0!s} -c select 1;".format(seconds), cur=cur))
-        test_asserts(watch_query("-c {0!s} select 1;".format(seconds), cur=cur))
+        test_asserts(watch_query(f"{seconds} -c select 1;", cur=cur))
+        test_asserts(watch_query(f"-c {seconds} select 1;", cur=cur))
 
 
 def test_split_sql_by_delimiter():
     for delimiter_str in (";", "$", "😀"):
         mycli.packages.special.set_delimiter(delimiter_str)
-        sql_input = "select 1{} select \ufffc2".format(delimiter_str)
+        sql_input = f"select 1{delimiter_str} select \ufffc2"
         queries = ("select 1", "select \ufffc2")
         for query, parsed_query in zip(queries, mycli.packages.special.split_queries(sql_input)):
             assert query == parsed_query
